@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2014-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2014-2024 Savoir-faire Linux Inc.
  *
  *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
  *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
@@ -20,8 +20,9 @@
 #pragma once
 
 #include "jamidht/conversationrepository.h"
-#include "jami/datatransfer_interface.h"
 #include "conversationrepository.h"
+#include "swarm/swarm_protocol.h"
+#include "jami/conversation_interface.h"
 
 #include <json/json.h>
 #include <msgpack.hpp>
@@ -33,6 +34,12 @@
 #include <memory>
 #include <set>
 
+#include <asio.hpp>
+
+namespace dhtnet {
+class ChannelSocket;
+} // namespace dhtnet
+
 namespace jami {
 
 namespace ConversationMapKeys {
@@ -85,6 +92,13 @@ struct ConversationRequest
         return m.size() == om.size() && std::equal(m.begin(), m.end(), om.begin());
     }
 
+    bool isOneToOne() const {
+        try {
+            return metadatas.at("mode") == "0";
+        } catch (...) {}
+        return true;
+    }
+
     MSGPACK_DEFINE_MAP(from, conversationId, metadatas, received, declined)
 };
 
@@ -98,7 +112,15 @@ struct ConvInfo
     std::string lastDisplayed {};
 
     ConvInfo() = default;
-    ConvInfo(const Json::Value& json);
+    ConvInfo(const ConvInfo&) = default;
+    ConvInfo(ConvInfo&&) = default;
+    ConvInfo(const std::string& id) : id(id) {};
+    explicit ConvInfo(const Json::Value& json);
+
+    bool isRemoved() const { return removed >= created; }
+
+    ConvInfo& operator=(const ConvInfo&) = default;
+    ConvInfo& operator=(ConvInfo&&) = default;
 
     Json::Value toJson() const;
 
@@ -108,35 +130,63 @@ struct ConvInfo
 class JamiAccount;
 class ConversationRepository;
 class TransferManager;
-class ChannelSocket;
 enum class ConversationMode;
 
 using OnPullCb = std::function<void(bool fetchOk)>;
 using OnLoadMessages
     = std::function<void(std::vector<std::map<std::string, std::string>>&& messages)>;
+using OnLoadMessages2
+    = std::function<void(std::vector<libjami::SwarmMessage>&& messages)>;
 using OnCommitCb = std::function<void(const std::string&)>;
 using OnDoneCb = std::function<void(bool, const std::string&)>;
 using OnMultiDoneCb = std::function<void(const std::vector<std::string>&)>;
+using OnMembersChanged = std::function<void(const std::vector<std::string>&)>;
+using DeviceId = dht::PkId;
+using GitSocketList = std::map<DeviceId, std::shared_ptr<dhtnet::ChannelSocket>>;
+using ChannelCb = std::function<bool(const std::shared_ptr<dhtnet::ChannelSocket>&)>;
+using NeedSocketCb
+    = std::function<void(const std::string&, const std::string&, ChannelCb&&, const std::string&)>;
 
 class Conversation : public std::enable_shared_from_this<Conversation>
 {
 public:
-    Conversation(const std::weak_ptr<JamiAccount>& account,
+    Conversation(const std::shared_ptr<JamiAccount>& account,
                  ConversationMode mode,
                  const std::string& otherMember = "");
-    Conversation(const std::weak_ptr<JamiAccount>& account, const std::string& conversationId = "");
-    Conversation(const std::weak_ptr<JamiAccount>& account,
+    Conversation(const std::shared_ptr<JamiAccount>& account,
+                 const std::string& conversationId = "");
+    Conversation(const std::shared_ptr<JamiAccount>& account,
                  const std::string& remoteDevice,
                  const std::string& conversationId);
     ~Conversation();
 
+    /**
+     * Print the state of the DRT linked to the conversation
+     */
+    void monitor();
+
+#ifdef LIBJAMI_TESTABLE
+    enum class BootstrapStatus { FAILED, FALLBACK, SUCCESS };
+    /**
+     * Used by the tests to get whenever the DRT is connected/disconnected
+     */
+    void onBootstrapStatus(const std::function<void(std::string, BootstrapStatus)>& cb);
+#endif
+
+    /**
+     * Bootstrap swarm manager to other peers
+     * @param onBootstraped     Callback called when connection is successfully established
+     * @param knownDevices      List of account's known devices
+     */
+    void bootstrap(std::function<void()> onBootstraped, const std::vector<DeviceId>& knownDevices);
+
     /**
      * Refresh active calls.
      * @note: If the host crash during a call, when initializing, we need to update
      * and commit all the crashed calls
      * @return  Commits added
      */
-    std::vector<std::string> refreshActiveCalls();
+    std::vector<std::string> commitsEndedCalls();
 
     /**
      * Add a callback to update upper layers
@@ -146,6 +196,23 @@ public:
     void onLastDisplayedUpdated(
         std::function<void(const std::string&, const std::string&)>&& lastDisplayedUpdatedCb);
 
+    void onMembersChanged(OnMembersChanged&& cb);
+
+    /**
+     * Set the callback that will be called whenever a new socket will be needed
+     * @param cb
+     */
+    void onNeedSocket(NeedSocketCb cb);
+    /**
+     * Add swarm connection to the DRT
+     * @param channel       Related channel
+     */
+    void addSwarmChannel(std::shared_ptr<dhtnet::ChannelSocket> channel);
+
+    /**
+     * Get conversation's id
+     * @return conversation Id
+     */
     std::string id() const;
 
     // Member management
@@ -183,6 +250,24 @@ public:
                                                      MemberRole::LEFT,
                                                      MemberRole::BANNED}) const;
 
+    /**
+     * Get peers to sync with. This is mostly managed by the DRT
+     * @return some mobile nodes and all connected nodes
+     */
+    std::vector<NodeId> peersToSyncWith() const;
+    /**
+     * Check if we're at least connected to one node
+     * @return if the DRT is connected
+     */
+    bool isBootstraped() const;
+    /**
+     * Retrieve the uri from a deviceId
+     * @note used by swarm manager (peersToSyncWith)
+     * @param deviceId
+     * @return corresponding issuer
+     */
+    std::string uriFromDevice(const std::string& deviceId) const;
+
     /**
      * Join a conversation
      * @return commit id to send
@@ -214,7 +299,17 @@ public:
      * @param cb        The callback when loaded
      * @param options   The log options
      */
-    void loadMessages(const OnLoadMessages& cb, const LogOptions& options);
+    void loadMessages(OnLoadMessages cb, const LogOptions& options);
+    /**
+     * Get a range of messages
+     * @param cb        The callback when loaded
+     * @param options   The log options
+     */
+    void loadMessages2(const OnLoadMessages2& cb, const LogOptions& options);
+    /**
+     * Clear all cached messages
+     */
+    void clearCache();
     /**
      * Retrieve one commit
      * @param   commitId
@@ -382,6 +477,16 @@ public:
      */
     void updateLastDisplayed(const std::string& lastDisplayed);
 
+    /**
+     * Change last displayed for multiple uris
+     * @param map       New last displayed
+     */
+    void updateLastDisplayed(const std::map<std::string, std::string>& map);
+    /**
+     * Retrieve last displayed id
+     * @return displayed
+     */
+    std::map<std::string, std::string> displayed() const;
     /**
      * Retrieve how many interactions there is from HEAD to interactionId
      * @param toId      "" for getting the whole history
@@ -392,7 +497,6 @@ public:
     uint32_t countInteractions(const std::string& toId,
                                const std::string& fromId = "",
                                const std::string& authorUri = "") const;
-
     /**
      * Search in the conversation via a filter
      * @param req       Id of the request
@@ -431,6 +535,36 @@ public:
      */
     std::vector<std::map<std::string, std::string>> currentCalls() const;
 
+    /**
+     * Git operations will need a ChannelSocket for cloning/fetching commits
+     * Because libgit2 is a C library, we store the pointer in the corresponding conversation
+     * and the GitTransport will inject to libgit2 whenever needed
+     */
+    std::shared_ptr<dhtnet::ChannelSocket> gitSocket(const DeviceId& deviceId) const;
+    void addGitSocket(const DeviceId& deviceId, const std::shared_ptr<dhtnet::ChannelSocket>& socket);
+    void removeGitSocket(const DeviceId& deviceId);
+
+    /**
+     * Stop SwarmManager, bootstrap and gitSockets
+     */
+    void shutdownConnections();
+    /**
+     * Used to avoid multiple connections, we just check if we got a swarm channel with a specific
+     * device
+     * @param deviceId
+     */
+    bool hasSwarmChannel(const std::string& deviceId);
+
+    /**
+     * If we change from one network to one another, we will need to update the state of the connections
+     */
+    void connectivityChanged();
+
+    /**
+     * @return getAllNodes()    Nodes that are linked to the conversation
+    */
+    std::vector<jami::DeviceId> getDeviceIdList() const;
+
 private:
     std::shared_ptr<Conversation> shared()
     {
@@ -449,6 +583,15 @@ private:
         return std::static_pointer_cast<Conversation const>(shared_from_this());
     }
 
+    // Private because of weak()
+    /**
+     * Used by bootstrap() to launch the fallback
+     * @param ec
+     * @param members       Members to try to connect
+     */
+    void checkBootstrapMember(const asio::error_code& ec,
+                              std::vector<std::map<std::string, std::string>> members);
+
     class Impl;
     std::unique_ptr<Impl> pimpl_;
 };
