@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *
  *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
  *
@@ -24,7 +24,6 @@
 
 #include "audio/ringbufferpool.h"
 #include "audio/ringbuffer.h"
-#include "audio/dcblocker.h"
 #include "libav_utils.h"
 #include "manager.h"
 #include "logger.h"
@@ -55,7 +54,7 @@ OpenSLLayer::startStream(AudioDeviceType stream)
 {
     using namespace std::placeholders;
 
-    std::lock_guard<std::mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
     if (!engineObject_)
         initAudioEngine();
 
@@ -94,7 +93,7 @@ OpenSLLayer::startStream(AudioDeviceType stream)
         }
     } else if (stream == AudioDeviceType::CAPTURE) {
         if (not recorder_) {
-            std::lock_guard<std::mutex> lck(recMtx);
+            std::lock_guard lck(recMtx);
             try {
                 recorder_.reset(
                     new opensl::AudioRecorder(hardwareFormat_, hardwareBuffSize_, engineInterface_));
@@ -116,7 +115,7 @@ OpenSLLayer::startStream(AudioDeviceType stream)
 void
 OpenSLLayer::stopStream(AudioDeviceType stream)
 {
-    std::lock_guard<std::mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
     if (!engineObject_)
         return; // bufs_ should be initialized
     JAMI_WARN("Stopping OpenSL audio layer for type %u", (unsigned) stream);
@@ -176,7 +175,7 @@ OpenSLLayer::initAudioEngine()
     std::vector<int32_t> hw_infos;
     hw_infos.reserve(4);
     emitSignal<libjami::ConfigurationSignal::GetHardwareAudioFormat>(&hw_infos);
-    hardwareFormat_ = AudioFormat(hw_infos[0], 1); // Mono on Android
+    hardwareFormat_ = AudioFormat(hw_infos[0], 1, AV_SAMPLE_FMT_FLT); // Mono on Android
     hardwareBuffSize_ = hw_infos[1];
     hardwareFormatAvailable(hardwareFormat_, hardwareBuffSize_);
 
@@ -185,9 +184,9 @@ OpenSLLayer::initAudioEngine()
     SLASSERT((*engineObject_)->GetInterface(engineObject_, SL_IID_ENGINE, &engineInterface_));
 
     size_t bufSize = hardwareBuffSize_ * hardwareFormat_.getBytesPerFrame();
-    JAMI_DBG("OpenSL init: using buffer of %zu bytes to support %s with %zu samples per channel",
+    JAMI_LOG("OpenSL init: using buffer of {:d} bytes to support {} with {:d} samples per channel",
              bufSize,
-             hardwareFormat_.toString().c_str(),
+             hardwareFormat_.toString(),
              hardwareBuffSize_);
     bufs_ = allocateSampleBufs(BUF_COUNT * 3, bufSize);
     for (int i = 0; i < BUF_COUNT; i++)
@@ -267,8 +266,7 @@ OpenSLLayer::engineServicePlay()
     sample_buf* buf;
     while (player_ and freePlayBufQueue_.front(&buf)) {
         if (auto dat = getToPlay(hardwareFormat_, hardwareBuffSize_)) {
-            buf->size_ = dat->pointer()->nb_samples * dat->pointer()->channels
-                         * sizeof(AudioSample);
+            buf->size_ = dat->pointer()->nb_samples * dat->getFormat().getBytesPerFrame();
             if (buf->size_ > buf->cap_) {
                 JAMI_ERR("buf->size_(%zu) > buf->cap_(%zu)", buf->size_, buf->cap_);
                 break;
@@ -280,9 +278,7 @@ OpenSLLayer::engineServicePlay()
                          dat->pointer()->nb_samples);
                 break;
             }
-            std::copy_n((const AudioSample*) dat->pointer()->data[0],
-                        dat->pointer()->nb_samples,
-                        (AudioSample*) buf->buf_);
+            memcpy(buf->buf_, dat->pointer()->data[0], buf->size_);
             if (!playBufQueue_.push(buf)) {
                 JAMI_WARN("playThread player_ PLAY_KICKSTART_BUFFER_COUNT 1");
                 break;
@@ -300,8 +296,7 @@ OpenSLLayer::engineServiceRing()
     sample_buf* buf;
     while (ringtone_ and freeRingBufQueue_.front(&buf)) {
         if (auto dat = getToRing(hardwareFormat_, hardwareBuffSize_)) {
-            buf->size_ = dat->pointer()->nb_samples * dat->pointer()->channels
-                         * sizeof(AudioSample);
+            buf->size_ = dat->pointer()->nb_samples * dat->getFormat().getBytesPerFrame();
             if (buf->size_ > buf->cap_) {
                 JAMI_ERR("buf->size_(%zu) > buf->cap_(%zu)", buf->size_, buf->cap_);
                 break;
@@ -313,9 +308,7 @@ OpenSLLayer::engineServiceRing()
                          dat->pointer()->nb_samples);
                 break;
             }
-            std::copy_n((const AudioSample*) dat->pointer()->data[0],
-                        dat->pointer()->nb_samples,
-                        (AudioSample*) buf->buf_);
+            memcpy(buf->buf_, dat->pointer()->data[0], buf->size_);
             if (!ringBufQueue_.push(buf)) {
                 JAMI_WARN("playThread ringtone_ PLAY_KICKSTART_BUFFER_COUNT 1");
                 break;
@@ -360,9 +353,7 @@ OpenSLLayer::startAudioCapture()
                     if (isCaptureMuted_)
                         libav_utils::fillWithSilence(out->pointer());
                     else
-                        std::copy_n((const AudioSample*) buf->buf_,
-                                    nb_samples,
-                                    (AudioSample*) out->pointer()->data[0]);
+                        memcpy(out->pointer()->data[0], buf->buf_, buf->size_);
                     putRecorded(std::move(out));
                 }
                 buf->size_ = 0;
@@ -381,7 +372,7 @@ OpenSLLayer::stopAudioCapture()
     JAMI_DBG("Stop audio capture");
 
     {
-        std::lock_guard<std::mutex> lck(recMtx);
+        std::lock_guard lck(recMtx);
         if (recorder_) {
             recorder_->stop();
             recorder_.reset();
