@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
  *
  *  Author: Tristan Matthews <tristan.matthews@savoirfairelinux.com>
  *  Author: Guillaume Roguez <Guillaume.Roguez@savoirfairelinux.com>
@@ -25,10 +25,10 @@
 #include "video_sender.h"
 #include "video_receive_thread.h"
 #include "video_mixer.h"
-#include "connectivity/ice_socket.h"
 #include "socket_pair.h"
 #include "sip/sipvoiplink.h" // for enqueueKeyframeRequest
 #include "manager.h"
+#include "media_const.h"
 #ifdef ENABLE_PLUGIN
 #include "plugin/streamdata.h"
 #include "plugin/jamipluginmanager.h"
@@ -41,6 +41,9 @@
 
 #include "account_const.h"
 
+#include <dhtnet/ice_socket.h>
+
+#include <asio/io_context.hpp>
 #include <sstream>
 #include <map>
 #include <string>
@@ -61,21 +64,24 @@ constexpr auto DELAY_AFTER_REMB_DEC = std::chrono::milliseconds(500);
 
 VideoRtpSession::VideoRtpSession(const string& callId,
                                  const string& streamId,
-                                 const DeviceParams& localVideoParams)
+                                 const DeviceParams& localVideoParams,
+                                 const std::shared_ptr<MediaRecorder>& rec)
     : RtpSession(callId, streamId, MediaType::MEDIA_VIDEO)
     , localVideoParams_(localVideoParams)
     , videoBitrateInfo_ {}
     , rtcpCheckerThread_([] { return true; }, [this] { processRtcpChecker(); }, [] {})
+    , cc(std::make_unique<CongestionControl>())
 {
+    recorder_ = rec;
     setupVideoBitrateInfo(); // reset bitrate
-    cc = std::make_unique<CongestionControl>();
-    JAMI_DBG("[%p] Video RTP session created for call %s", this, callId_.c_str());
+    JAMI_LOG("[{:p}] Video RTP session created for call {} (recorder {:p})", fmt::ptr(this), callId_, fmt::ptr(recorder_));
 }
 
 VideoRtpSession::~VideoRtpSession()
 {
+    deinitRecorder();
     stop();
-    JAMI_DBG("[%p] Video RTP session destroyed", this);
+    JAMI_LOG("[{:p}] Video RTP session destroyed", fmt::ptr(this));
 }
 
 const VideoBitrateInfo&
@@ -90,6 +96,13 @@ void
 VideoRtpSession::updateMedia(const MediaDescription& send, const MediaDescription& receive)
 {
     BaseType::updateMedia(send, receive);
+    // adjust send->codec bitrate info for higher video resolutions
+    auto codecVideo = std::static_pointer_cast<jami::SystemVideoCodecInfo>(send_.codec);
+    if (codecVideo) {
+        auto const pixels = localVideoParams_.height * localVideoParams_.width;
+        codecVideo->bitrate = std::max((unsigned int)(pixels * 0.001), SystemCodecInfo::DEFAULT_VIDEO_BITRATE);
+        codecVideo->maxBitrate = std::max((unsigned int)(pixels * 0.0015), SystemCodecInfo::DEFAULT_MAX_BITRATE);
+    }
     setupVideoBitrateInfo();
 }
 
@@ -102,7 +115,7 @@ VideoRtpSession::setRequestKeyFrameCallback(std::function<void(void)> cb)
 void
 VideoRtpSession::startSender()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     JAMI_DBG("[%p] Start video RTP sender: input [%s] - muted [%s]",
              this,
@@ -125,10 +138,16 @@ VideoRtpSession::startSender()
         }
 
         if (not conference_) {
-            auto input = getVideoInput(input_);
-            videoLocal_ = input;
-            if (input) {
-                auto newParams = input->getParams();
+            videoLocal_ = getVideoInput(input_);
+            if (videoLocal_) {
+                videoLocal_->setRecorderCallback(
+                    [w=weak_from_this()](const MediaStream& ms) {
+                        Manager::instance().ioContext()->post([w=std::move(w), ms]() {
+                            if (auto shared = w.lock())
+                                shared->attachLocalRecorder(ms);
+                        });
+                    });
+                auto newParams = videoLocal_->getParams();
                 try {
                     if (newParams.valid()
                         && newParams.wait_for(NEWPARAMS_TIMEOUT) == std::future_status::ready) {
@@ -146,18 +165,15 @@ VideoRtpSession::startSender()
                 return;
             }
 
-#ifdef __ANDROID__
-            if (auto input1 = std::static_pointer_cast<VideoInput>(videoLocal_)) {
-                input1->setupSink();
-                input1->setFrameSize(localVideoParams_.width, localVideoParams_.height);
-            }
+#if (defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS))
+            videoLocal_->setupSink(localVideoParams_.width, localVideoParams_.height);
 #endif
         }
 
         // be sure to not send any packets before saving last RTP seq value
         socketPair_->stopSendOp();
 
-        auto codecVideo = std::static_pointer_cast<jami::AccountVideoCodecInfo>(send_.codec);
+        auto codecVideo = std::static_pointer_cast<jami::SystemVideoCodecInfo>(send_.codec);
         auto autoQuality = codecVideo->isAutoQualityEnabled;
 
         send_.linkableHW = conference_ == nullptr;
@@ -202,13 +218,16 @@ VideoRtpSession::startSender()
             rtcpCheckerThread_.start();
         else if (not autoQuality and rtcpCheckerThread_.isRunning())
             rtcpCheckerThread_.join();
+        // Block reads to received feedback packets
+        if(socketPair_)
+            socketPair_->setReadBlockingMode(true);
     }
 }
 
 void
 VideoRtpSession::restartSender()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     // ensure that start has been called before restart
     if (not socketPair_)
@@ -223,7 +242,7 @@ VideoRtpSession::restartSender()
 }
 
 void
-VideoRtpSession::stopSender()
+VideoRtpSession::stopSender(bool forceStopSocket)
 {
     // Concurrency protection must be done by caller.
 
@@ -240,8 +259,13 @@ VideoRtpSession::stopSender()
         sender_.reset();
     }
 
-    if (socketPair_)
-        socketPair_->stopSendOp();
+    if (socketPair_) {
+        bool const isReceivingVideo = receive_.enabled && !receive_.onHold;
+        if(forceStopSocket || !isReceivingVideo) {
+            socketPair_->stopSendOp();
+            socketPair_->setReadBlockingMode(false);
+        }
+    }
 }
 
 void
@@ -257,6 +281,10 @@ VideoRtpSession::startReceiver()
         receiveThread_.reset(
             new VideoReceiveThread(callId_, !conference_, receive_.receiving_sdp, mtu_));
 
+        // ensure that start has been called
+        if (not socketPair_)
+            return;
+
         // XXX keyframe requests can timeout if unanswered
         receiveThread_->addIOContext(*socketPair_);
         receiveThread_->setSuccessfulSetupCb(onSuccessfulSetup_);
@@ -272,7 +300,12 @@ VideoRtpSession::startReceiver()
             if (activeStream)
                 videoMixer_->setActiveStream(streamId_);
         }
-
+        receiveThread_->setRecorderCallback([w=weak_from_this()](const MediaStream& ms) {
+            Manager::instance().ioContext()->post([w=std::move(w), ms]() {
+                if (auto shared = w.lock())
+                    shared->attachRemoteRecorder(ms);
+            });
+        });
     } else {
         JAMI_DBG("[%p] Video receiver disabled", this);
         if (receiveThread_ and videoMixer_ and conference_) {
@@ -291,7 +324,7 @@ VideoRtpSession::startReceiver()
 }
 
 void
-VideoRtpSession::stopReceiver()
+VideoRtpSession::stopReceiver(bool forceStopSocket)
 {
     // Concurrency protection must be done by caller.
 
@@ -313,17 +346,29 @@ VideoRtpSession::stopReceiver()
     // We need to disable the read operation, otherwise the
     // receiver thread will block since the peer stopped sending
     // RTP packets.
-    if (socketPair_)
-        socketPair_->setReadBlockingMode(false);
+    bool const isSendingVideo = send_.enabled && !send_.onHold;
+    if (socketPair_) {
+        if (forceStopSocket || !isSendingVideo) {
+            socketPair_->setReadBlockingMode(false);
+            socketPair_->stopSendOp();
+        }
+    }
 
-    receiveThread_->stopLoop();
+    auto ms = receiveThread_->getInfo();
+    if (auto ob = recorder_->getStream(ms.name)) {
+        receiveThread_->detach(ob);
+        recorder_->removeStream(ms);
+    }
+
+    if(forceStopSocket || !isSendingVideo)
+        receiveThread_->stopLoop();
     receiveThread_->stopSink();
 }
 
 void
-VideoRtpSession::start(std::unique_ptr<IceSocket> rtp_sock, std::unique_ptr<IceSocket> rtcp_sock)
+VideoRtpSession::start(std::unique_ptr<dhtnet::IceSocket> rtp_sock, std::unique_ptr<dhtnet::IceSocket> rtcp_sock)
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     if (not send_.enabled and not receive_.enabled) {
         stop();
@@ -380,10 +425,13 @@ VideoRtpSession::start(std::unique_ptr<IceSocket> rtp_sock, std::unique_ptr<IceS
 void
 VideoRtpSession::stop()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
-    stopSender();
-    stopReceiver();
+    stopSender(true);
+    stopReceiver(true);
+
+    if (socketPair_)
+        socketPair_->interrupt();
 
     rtcpCheckerThread_.join();
 
@@ -394,8 +442,6 @@ VideoRtpSession::stop()
     videoBitrateInfo_.videoBitrateCurrent = SystemCodecInfo::DEFAULT_VIDEO_BITRATE;
     storeVideoBitrateInfo();
 
-    if (socketPair_)
-        socketPair_->interrupt();
     socketPair_.reset();
     videoLocal_.reset();
 }
@@ -403,11 +449,7 @@ VideoRtpSession::stop()
 void
 VideoRtpSession::setMuted(bool mute, Direction dir)
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
-
-    // ensure that start has been called before setmuted
-    if (not socketPair_)
-        return;
+    std::lock_guard lock(mutex_);
 
     // Sender
     if (dir == Direction::SEND) {
@@ -417,6 +459,13 @@ VideoRtpSession::setMuted(bool mute, Direction dir)
         }
 
         if ((send_.onHold = mute)) {
+            if (videoLocal_) {
+                auto ms = videoLocal_->getInfo();
+                if (auto ob = recorder_->getStream(ms.name)) {
+                    videoLocal_->detach(ob);
+                    recorder_->removeStream(ms);
+                }
+            }
             stopSender();
         } else {
             restartSender();
@@ -431,6 +480,13 @@ VideoRtpSession::setMuted(bool mute, Direction dir)
     }
 
     if ((receive_.onHold = mute)) {
+        if (receiveThread_) {
+            auto ms = receiveThread_->getInfo();
+            if (auto ob = recorder_->getStream(ms.name)) {
+                receiveThread_->detach(ob);
+                recorder_->removeStream(ms);
+            }
+        }
         stopReceiver();
     } else {
         startReceiver();
@@ -443,7 +499,7 @@ VideoRtpSession::setMuted(bool mute, Direction dir)
 void
 VideoRtpSession::forceKeyFrame()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 #if __ANDROID__
     if (videoLocal_)
         emitSignal<libjami::VideoSignal::RequestKeyFrame>(videoLocal_->getName());
@@ -510,7 +566,7 @@ VideoRtpSession::setupConferenceVideoPipeline(Conference& conference, Direction
 void
 VideoRtpSession::enterConference(Conference& conference)
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     exitConference();
 
@@ -531,7 +587,7 @@ VideoRtpSession::enterConference(Conference& conference)
 void
 VideoRtpSession::exitConference()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     if (!conference_)
         return;
@@ -663,9 +719,13 @@ VideoRtpSession::delayProcessing(int br)
     int newBitrate = videoBitrateInfo_.videoBitrateCurrent;
     if (br == 0x6803)
         newBitrate *= 0.85f;
-    else if (br == 0x7378)
-        newBitrate *= 1.05f;
-    else
+    else if (br == 0x7378) {
+        auto now = clock::now();
+        auto msSinceLastDecrease = std::chrono::duration_cast<std::chrono::milliseconds>(
+            now - lastBitrateDecrease);
+        auto increaseCoefficient = std::min(msSinceLastDecrease.count() / 600000.0f + 1.0f, 1.05f);
+        newBitrate *= increaseCoefficient;
+    } else
         return;
 
     setNewBitrate(newBitrate);
@@ -677,6 +737,9 @@ VideoRtpSession::setNewBitrate(unsigned int newBR)
     newBR = std::max(newBR, videoBitrateInfo_.videoBitrateMin);
     newBR = std::min(newBR, videoBitrateInfo_.videoBitrateMax);
 
+    if (newBR < videoBitrateInfo_.videoBitrateCurrent)
+        lastBitrateDecrease = clock::now();
+
     if (videoBitrateInfo_.videoBitrateCurrent != newBR) {
         videoBitrateInfo_.videoBitrateCurrent = newBR;
         storeVideoBitrateInfo();
@@ -701,16 +764,15 @@ VideoRtpSession::setNewBitrate(unsigned int newBR)
 void
 VideoRtpSession::setupVideoBitrateInfo()
 {
-    auto codecVideo = std::static_pointer_cast<jami::AccountVideoCodecInfo>(send_.codec);
+    auto codecVideo = std::static_pointer_cast<jami::SystemVideoCodecInfo>(send_.codec);
     if (codecVideo) {
-        auto& info = codecVideo->systemCodecInfo;
         videoBitrateInfo_ = {
             codecVideo->bitrate,
-            info.minBitrate,
-            info.maxBitrate,
+            codecVideo->minBitrate,
+            codecVideo->maxBitrate,
             codecVideo->quality,
-            info.minQuality,
-            info.maxQuality,
+            codecVideo->minQuality,
+            codecVideo->maxQuality,
             videoBitrateInfo_.cptBitrateChecking,
             videoBitrateInfo_.maxBitrateChecking,
             videoBitrateInfo_.packetLostThreshold,
@@ -724,7 +786,7 @@ VideoRtpSession::setupVideoBitrateInfo()
 void
 VideoRtpSession::storeVideoBitrateInfo()
 {
-    if (auto codecVideo = std::static_pointer_cast<jami::AccountVideoCodecInfo>(send_.codec)) {
+    if (auto codecVideo = std::static_pointer_cast<jami::SystemVideoCodecInfo>(send_.codec)) {
         codecVideo->bitrate = videoBitrateInfo_.videoBitrateCurrent;
         codecVideo->quality = videoBitrateInfo_.videoQualityCurrent;
     }
@@ -738,35 +800,67 @@ VideoRtpSession::processRtcpChecker()
 }
 
 void
-VideoRtpSession::initRecorder(std::shared_ptr<MediaRecorder>& rec)
+VideoRtpSession::attachRemoteRecorder(const MediaStream& ms)
 {
-    if (receiveThread_) {
-        if (auto ob = rec->addStream(receiveThread_->getInfo())) {
-            receiveThread_->attach(ob);
-        }
-    }
-    if (Manager::instance().videoPreferences.getRecordPreview()) {
-        if (auto input = std::static_pointer_cast<VideoInput>(videoLocal_)) {
-            if (auto ob = rec->addStream(input->getInfo())) {
-                input->attach(ob);
-            }
-        }
+    std::lock_guard lock(mutex_);
+    if (!recorder_ || !receiveThread_)
+        return;
+    if (auto ob = recorder_->addStream(ms)) {
+        receiveThread_->attach(ob);
     }
 }
 
 void
-VideoRtpSession::deinitRecorder(std::shared_ptr<MediaRecorder>& rec)
+VideoRtpSession::attachLocalRecorder(const MediaStream& ms)
 {
-    if (!rec)
+    std::lock_guard lock(mutex_);
+    if (!recorder_ || !videoLocal_ || !Manager::instance().videoPreferences.getRecordPreview())
+        return;
+    if (auto ob = recorder_->addStream(ms)) {
+        videoLocal_->attach(ob);
+    }
+}
+
+void
+VideoRtpSession::initRecorder()
+{
+    if (!recorder_)
         return;
     if (receiveThread_) {
-        if (auto ob = rec->getStream(receiveThread_->getInfo().name)) {
+        receiveThread_->setRecorderCallback([w=weak_from_this()](const MediaStream& ms) {
+            Manager::instance().ioContext()->post([w=std::move(w), ms]() {
+                if (auto shared = w.lock())
+                    shared->attachRemoteRecorder(ms);
+            });
+        });
+    }
+    if (videoLocal_ && !send_.onHold) {
+        videoLocal_->setRecorderCallback([w=weak_from_this()](const MediaStream& ms) {
+            Manager::instance().ioContext()->post([w=std::move(w), ms]() {
+                if (auto shared = w.lock())
+                    shared->attachLocalRecorder(ms);
+            });
+        });
+    }
+}
+
+void
+VideoRtpSession::deinitRecorder()
+{
+    if (!recorder_)
+        return;
+    if (receiveThread_) {
+        auto ms = receiveThread_->getInfo();
+        if (auto ob = recorder_->getStream(ms.name)) {
             receiveThread_->detach(ob);
+            recorder_->removeStream(ms);
         }
     }
-    if (auto input = std::static_pointer_cast<VideoInput>(videoLocal_)) {
-        if (auto ob = rec->getStream(input->getInfo().name)) {
-            input->detach(ob);
+    if (videoLocal_) {
+        auto ms = videoLocal_->getInfo();
+        if (auto ob = recorder_->getStream(ms.name)) {
+            videoLocal_->detach(ob);
+            recorder_->removeStream(ms);
         }
     }
 }
